# `reconner.validation`

`reconner.validation` provides a set of utility functions to fix and validate annotations to ensure consistency and no overlapping entities are set.
These functions are useful to run before any of the functionality in `reconner.insights` or `reconner.stats`.

---
## API

::: reconner.validation.json_to_examples
    :docstring:

::: reconner.validation.fix_annotations_format
    :docstring:

::: reconner.validation.filter_overlaps
    :docstring:
